/*
 * Copyright 2011 JOHK Software
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.wesleyhome.johksoftware.utilities;

import java.util.Calendar;
import java.util.Date;

/**
 * Utility class for dealing with dates.
 * 
 * @author Justin Wesley
 *
 */
public class DateUtils {

	/**
	 * Don't allow instantiation
	 */
	private DateUtils() {
	}
	/**
	 * Determines if a date is within a date range
	 * 
	 * @param check the date to check
	 * @param from the begin date of the range
	 * @param to the end date of the range
	 * @return true is check is between from and to
	 */
	public static boolean isBetween(final Date check, final Date from, final Date to) {
		if (to.before(from)) {
			throw new IllegalArgumentException("From date must be on or before to date");
		}
		return isOnOrAfter(check, from) && isOnOrBefore(check, to);
	}

	/**
	 * Determines if a date is on or after another date
	 * 
	 * @param d1 the date to check
	 * @param d2 the date to compare
	 * @return true if check date is on or after compare date
	 */
	public static boolean isOnOrAfter(final Date d1, final Date d2) {
		return org.apache.commons.lang3.time.DateUtils.isSameDay(d1, d2) || d1.after(d2);
	}

	/**
	 * Determines if a date is on or before another date
	 * 
	 * @param d1 the date to check
	 * @param d2 the date to compare
	 * @return true if check date is on or before compare date
	 */
	public static boolean isOnOrBefore(final Date d1, final Date d2) {
		return org.apache.commons.lang3.time.DateUtils.isSameDay(d1, d2) || d1.before(d2);
	}

	public static Date getDate(final int year, final int month, final int day) {
		Calendar c = Calendar.getInstance();
		c.set(year, month, day);
		return c.getTime();
	}
}
