/*
 * Copyright 2011 JOHK Software
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.wesleyhome.johksoftware.utilities;

import org.apache.commons.lang3.text.WordUtils;

/**
 * @author Justin Wesley
 * @since 1.0
 *
 */
public final class StringUtils {

	private StringUtils() {
	}

	/**
	 * This will take a camel case string and humanize it and capitalize it.
	 * 
	 * <code>
	 * humanizeString("thisIsCamelCase") = "This Is Camel Case"
	 * humanizeString("isGH_Country") = "Is Gh Country"
	 * </code>
	 * @param camelCase
	 * @return
	 */
	public static String humanizeString(final String camelCaseString) {
		return humanizeString(camelCaseString, true);
	}

	/**
	 * This will take a camel case string and humanize it.
	 * 
	 * <code>
	 * humanizeString("thisIsCamelCase") = "this is camel case"
	 * humanizeString("isGH_Country") = "is gh country"
	 * </code>
	 * @param camelCase
	 * @return
	 */
	public static String humanizeString(final String camelCaseString, final boolean capitalize) {
		StringBuilder sb = new StringBuilder();
		boolean isPreviousUpperCase = true, isPreviousSpace = false;
		for (int i = 0; i < camelCaseString.length(); i++) {
			char c = camelCaseString.charAt(i);
			if (c == '_') {
				isPreviousUpperCase = false;
				isPreviousSpace = true;
				sb.append(' ');
				continue;
			}
			if (Character.isUpperCase(c)) {
				if (isPreviousUpperCase) {
					sb.append(c);
				} else {
					c = Character.toLowerCase(c);
					if (!isPreviousSpace) {
						sb.append(' ');
					}
					sb.append(c);
					isPreviousUpperCase = true;
				}
			} else {
				isPreviousUpperCase = false;
				sb.append(c);
			}
			isPreviousSpace = false;
		}
		if (capitalize) {
			return WordUtils.capitalize(sb.toString());
		}
		return sb.toString();
	}
}
