/*
 * Copyright 2011 JOHK Software
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.wesleyhome.johksoftware.utilities.reflection;

import java.math.BigDecimal;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Arrays;
import java.util.Calendar;
import java.util.List;

public enum ClassType {
	BYTE(Byte.class, Byte.TYPE),
	SHORT(Short.class, Short.TYPE),
	INTEGER(Integer.class, Integer.TYPE),
	LONG(Long.class, Long.TYPE),
	FLOAT(Float.class, Float.TYPE),
	BIG_DECMIAL(BigDecimal.class),
	DOUBLE(Double.class, Double.TYPE),
	BOOLEAN(Boolean.class, Boolean.TYPE),
	SQL_DATE(java.sql.Date.class),
	DATE(java.util.Date.class),
	TIMESTAMP(Timestamp.class),
	TIME(Time.class),
	CALENDAR(Calendar.class),
	URL(java.net.URL.class),
	STRING(String.class),
	ARRAY(byte[].class, int[].class, double[].class, String[].class),
	MAP(java.util.Map.class),
	CLASS(Class.class),
	OBJECT(Object.class),
	ENUM(Enum.class);

	private List<Class<?>> classes;

	private ClassType(final Class<?>... classes) {
		this.classes = Arrays.asList(classes);
	}

	public List<Class<?>> getClasses() {
		return classes;
	}

	public static ClassType getClassType(final Class<?> cls) {
		ClassType[] values = ClassType.values();
		for (ClassType classType : values) {
			if (classType.equals(ClassType.ENUM)) {
				if (cls.isEnum()) {
					return classType;
				}
			}
			if (classType.getClasses().contains(cls)) {
				return classType;
			}
		}
		return ClassType.OBJECT;
	}
}
